@@ -1,27 +1,35 @@
 """Entity Functionality and Classes"""
-# Standard Library Imports
 import copy
 import logging
 
 from collections import defaultdict
+from functools import partial
+from typing import Any, Dict
 from uuid import uuid4
 
-# Protean
-from protean.core.exceptions import (
+from protean.core.field.association import (
+    Association,
+    HasMany,
+    Reference,
+    _ReferenceField,
+)
+from protean.core.field.basic import Auto, Field
+from protean.core.field.embedded import ValueObject
+from protean.exceptions import (
     ConfigurationError,
     IncorrectUsageError,
     NotSupportedError,
     ValidationError,
 )
-from protean.core.field.association import Association, Reference
-from protean.core.field.basic import Auto, Field
-from protean.core.field.embedded import ValueObjectField
-from protean.domain import DomainObjects
 from protean.globals import current_domain
-from protean.utils import IdentityStrategy, IdentityType, inflection
-
-# Local/Relative Imports
-from ..core.field.association import _ReferenceField  # Relative path to private class
+from protean.utils import (
+    DomainObjects,
+    IdentityStrategy,
+    IdentityType,
+    derive_element_class,
+    generate_identity,
+    inflection,
+)
 
 logger = logging.getLogger("protean.domain.entity")
 
@@ -110,6 +118,15 @@ class _EntityMetaclass(type):
             if isinstance(attr_obj, (Association, Field, Reference)):
                 setattr(new_class, attr_name, attr_obj)
                 new_class.meta_.declared_fields[attr_name] = attr_obj
+            else:
+                if isinstance(attr_obj, BaseEntity):
+                    raise IncorrectUsageError(
+                        {
+                            "_entity": [
+                                f"'{attr_name}' of type '{type(attr_obj).__name__}' cannot be part of an entity."
+                            ]
+                        }
+                    )
 
     def _set_up_reference_fields(new_class):
         """Walk through relation fields and setup shadow attributes"""
@@ -124,7 +141,7 @@ class _EntityMetaclass(type):
         """Walk through value object fields and setup shadow attributes"""
         if new_class.meta_.declared_fields:
             for _, field in new_class.meta_.declared_fields.items():
-                if isinstance(field, ValueObjectField):
+                if isinstance(field, ValueObject):
                     shadow_fields = field.get_shadow_fields()
                     for shadow_field_name, shadow_field in shadow_fields:
                         new_class.meta_.value_object_fields[
@@ -142,9 +159,23 @@ class _EntityMetaclass(type):
                     for _, field in new_class.meta_.declared_fields.items()
                     if isinstance(field, (Field, Reference)) and field.identifier
                 )
+
+                # If the aggregate/entity has been marked abstract,
+                #   and contains an identifier field, raise exception
+                if new_class.meta_.abstract and new_class.meta_.id_field:
+                    raise IncorrectUsageError(
+                        {
+                            "_entity": [
+                                "Aggregates marked as abstract cannot have identity fields"
+                            ]
+                        }
+                    )
             except StopIteration:
                 # If no id field is declared then create one
-                new_class._create_id_field()
+                #   If the aggregate/entity is marked abstract,
+                #   avoid creating an identifier field.
+                if not new_class.meta_.abstract:
+                    new_class._create_id_field()
 
     def _create_id_field(new_class):
         """Create and return a default ID field that is Auto generated"""
@@ -167,7 +198,6 @@ class EntityMeta:
         defaults to underscore version of the Entity name.
     - ``provider``: the name of the datasource associated with this
         entity, default value is `default`.
-    - ``order_by``: default ordering of objects returned by filter queries.
 
     Also acts as a placeholder for generated entity fields like:
 
@@ -188,13 +218,6 @@ class EntityMeta:
         self.provider = getattr(meta, "provider", None) or "default"
         self.model = getattr(meta, "model", None)
 
-        # `order_by` can be provided either as a string or a tuple
-        ordering = getattr(meta, "order_by", ())
-        if isinstance(ordering, str):
-            self.order_by = (ordering,)
-        else:
-            self.order_by = tuple(ordering)
-
         # Initialize Options
         self.declared_fields = {}
         self.value_object_fields = {}
@@ -203,16 +226,6 @@ class EntityMeta:
 
         # Domain Attributes
         self.aggregate_cls = getattr(meta, "aggregate_cls", None)
-        self.bounded_context = getattr(meta, "bounded_context", None)
-
-    @property
-    def mandatory_fields(self):
-        """ Return the mandatory fields for this entity """
-        return {
-            field_name: field_obj
-            for field_name, field_obj in self.attributes.items()
-            if not isinstance(field_obj, Association) and field_obj.required
-        }
 
     @property
     def unique_fields(self):
@@ -235,7 +248,7 @@ class EntityMeta:
     def attributes(self):
         attributes_dict = {}
         for _, field_obj in self.declared_fields.items():
-            if isinstance(field_obj, ValueObjectField):
+            if isinstance(field_obj, ValueObject):
                 shadow_fields = field_obj.get_shadow_fields()
                 for _, shadow_field in shadow_fields:
                     attributes_dict[shadow_field.attribute_name] = shadow_field
@@ -336,6 +349,8 @@ class BaseEntity(metaclass=_EntityMetaclass):
 
     element_type = DomainObjects.ENTITY
 
+    META_OPTIONS = [("provider", "default"), ("model", None), ("aggregate_cls", None)]
+
     def __init__(self, *template, raise_errors=True, **kwargs):  # noqa: C901
         """
         Initialise the entity object.
@@ -368,6 +383,9 @@ class BaseEntity(metaclass=_EntityMetaclass):
         # Set up the storage for instance state
         self.state_ = _EntityState()
 
+        # Placeholder for temporary association values
+        self._temp_cache = defaultdict(lambda: defaultdict(dict))
+
         # Load the attributes based on the template
         loaded_fields = []
         for dictionary in template:
@@ -395,16 +413,14 @@ class BaseEntity(metaclass=_EntityMetaclass):
         #   and associated the vo with the entity
         # If the value object was already provided, it will not be overridden.
         for field_name, field_obj in self.meta_.declared_fields.items():
-            if isinstance(field_obj, (ValueObjectField)) and not getattr(
-                self, field_name
-            ):
+            if isinstance(field_obj, (ValueObject)) and not getattr(self, field_name):
                 attributes = [
                     (embedded_field.field_name, embedded_field.attribute_name)
                     for embedded_field in field_obj.embedded_fields.values()
                 ]
                 values = {name: kwargs.get(attr) for name, attr in attributes}
                 try:
-                    value_object = field_obj.value_object_cls.build(**values)
+                    value_object = field_obj.value_object_cls(**values)
                     # Set VO value only if the value object is not None/Empty
                     if value_object:
                         setattr(self, field_name, value_object)
@@ -420,7 +436,7 @@ class BaseEntity(metaclass=_EntityMetaclass):
             not getattr(self, self.meta_.id_field.field_name, None)
             and type(self.meta_.id_field) is Auto
         ):
-            setattr(self, self.meta_.id_field.field_name, self.generate_identity())
+            setattr(self, self.meta_.id_field.field_name, generate_identity())
             loaded_fields.append(self.meta_.id_field.field_name)
 
         # Load Associations
@@ -428,6 +444,21 @@ class BaseEntity(metaclass=_EntityMetaclass):
             if isinstance(field_obj, Association):
                 getattr(self, field_name)  # This refreshes the values in associations
 
+                # Set up add and remove methods. These are pseudo methods, `add_*` and
+                #   `remove_*` that point to the HasMany field's `add` and `remove`
+                #   methods. They are wrapped to ensure we pass the object that holds
+                #   the values and temp_cache.
+                if isinstance(field_obj, HasMany):
+                    setattr(self, f"add_{field_name}", partial(field_obj.add, self))
+                    setattr(
+                        self, f"remove_{field_name}", partial(field_obj.remove, self)
+                    )
+                    setattr(
+                        self,
+                        f"_mark_changed_{field_name}",
+                        partial(field_obj._mark_changed, self),
+                    )
+
         # Now load the remaining fields with a None value, which will fail
         # for required fields
         for field_name, field_obj in self.meta_.declared_fields.items():
@@ -437,7 +468,7 @@ class BaseEntity(metaclass=_EntityMetaclass):
                         setattr(self, field_name, None)
 
                         # If field is a VO, set underlying attributes to None as well
-                        if isinstance(field_obj, ValueObjectField):
+                        if isinstance(field_obj, ValueObject):
                             for embedded_field in field_obj.embedded_fields.values():
                                 setattr(self, embedded_field.attribute_name, None)
                     except ValidationError as err:
@@ -457,7 +488,7 @@ class BaseEntity(metaclass=_EntityMetaclass):
 
         # Raise any errors found during load
         if self.errors and self.raise_errors:
-            logger.error(self.errors)
+            logger.error(f"Error during initialization: {dict(self.errors)}")
             raise ValidationError(self.errors)
 
     def defaults(self):
@@ -474,12 +505,12 @@ class BaseEntity(metaclass=_EntityMetaclass):
     @classmethod
     def generate_identity(cls):
         """Generate Unique Identifier, based on configured strategy"""
-        if current_domain.config["IDENTITY_STRATEGY"] == IdentityStrategy.UUID:
-            if current_domain.config["IDENTITY_TYPE"] == IdentityType.INTEGER:
+        if current_domain.config["IDENTITY_STRATEGY"] == IdentityStrategy.UUID.value:
+            if current_domain.config["IDENTITY_TYPE"] == IdentityType.INTEGER.value:
                 return uuid4().int
-            elif current_domain.config["IDENTITY_TYPE"] == IdentityType.STRING:
+            elif current_domain.config["IDENTITY_TYPE"] == IdentityType.STRING.value:
                 return str(uuid4())
-            elif current_domain.config["IDENTITY_TYPE"] == IdentityType.UUID:
+            elif current_domain.config["IDENTITY_TYPE"] == IdentityType.UUID.value:
                 return uuid4()
             else:
                 raise ConfigurationError(
@@ -540,38 +571,26 @@ class BaseEntity(metaclass=_EntityMetaclass):
 
         # Raise any errors found during update
         if self.errors:
-            logger.error(self.errors)
+            logger.error(f"Errors on Update: {dict(self.errors)}")
             raise ValidationError(self.errors)
 
     def to_dict(self):
         """ Return entity data as a dictionary """
+        # FIXME Memoize this function
         field_values = {}
-        field_values = {
-            field_name: getattr(self, field_name, None)
-            for field_name, field_obj in self.meta_.declared_fields.items()
-            if not isinstance(field_obj, ValueObjectField)
-        }
 
-        # FIXME Simplify fetching and appending Value Object dict values
-        vo_fields = {
-            field_name: getattr(self, field_name, None)
-            for field_name, field_obj in self.meta_.declared_fields.items()
-            if isinstance(field_obj, ValueObjectField)
-        }
-
-        vo_field_values = {}
-        for vo_field_name, vo_field_obj in vo_fields.items():
-            if vo_field_obj:
-                vo_field_values.update(
-                    {
-                        vo_field_name
-                        + "_"
-                        + field_name: getattr(vo_field_obj, field_name, None)
-                        for field_name, field_obj in vo_field_obj.meta_.declared_fields.items()
-                    }
+        for field_name, field_obj in self.meta_.declared_fields.items():
+            if (
+                not isinstance(field_obj, (ValueObject, Reference))
+                and getattr(self, field_name, None) is not None
+            ):
+                field_values[field_name] = field_obj.as_dict(
+                    getattr(self, field_name, None)
                 )
+            elif isinstance(field_obj, ValueObject):
+                field_values.update(field_obj.as_dict(getattr(self, field_name, None)))
 
-        return {**field_values, **vo_field_values}
+        return field_values
 
     def __repr__(self):
         """Friendly repr for Entity"""
@@ -591,67 +610,48 @@ class BaseEntity(metaclass=_EntityMetaclass):
 
         return clone_copy
 
-
-class EntityFactory:
     @classmethod
-    def prep_class(cls, element_cls, **kwargs):
-        if issubclass(element_cls, BaseEntity):
-            new_element_cls = element_cls
-        else:
-            try:
-                new_dict = element_cls.__dict__.copy()
-                new_dict.pop("__dict__", None)  # Remove __dict__ to prevent recursion
+    def _extract_options(cls, **opts):
+        """A stand-in method for setting customized options on the Domain Element
 
-                new_element_cls = type(element_cls.__name__, (BaseEntity,), new_dict)
-            except BaseException as exc:
-                logger.debug("Error during Element registration:", repr(exc))
-                raise IncorrectUsageError(
-                    "Invalid class {element_cls.__name__} for type {element_type.value}"
-                    " (Error: {exc})",
-                )
-
-        cls._validate_entity_class(new_element_cls)
-
-        new_element_cls.meta_.provider = (
-            kwargs.pop("provider", None)
-            or (hasattr(new_element_cls, "meta_") and new_element_cls.meta_.provider)
-            or "default"
-        )
-        new_element_cls.meta_.model = (
-            kwargs.pop("model", None)
-            or (hasattr(new_element_cls, "meta_") and new_element_cls.meta_.model)
-            or None
-        )
-        new_element_cls.meta_.bounded_context = kwargs.pop("bounded_context", None) or (
-            hasattr(new_element_cls, "meta_") and new_element_cls.meta_.bounded_context
-        )
-        new_element_cls.meta_.aggregate_cls = (
-            kwargs.pop("aggregate_cls", None)
-            or (
-                hasattr(new_element_cls, "meta_")
-                and new_element_cls.meta_.aggregate_cls
-            )
-            or None
-        )
-
-        if not new_element_cls.meta_.aggregate_cls:
-            raise IncorrectUsageError(
-                f"Entity `{new_element_cls.__name__}` needs to be associated with an Aggregate"
-            )
-
-        return new_element_cls
+        Empty by default. To be overridden in each Element that expects or needs
+        specific options.
+        """
+        for key, default in cls.META_OPTIONS:
+            setattr(cls.meta_, key, cls._derive_preference(opts, key, default))
 
     @classmethod
-    def _validate_entity_class(cls, element_cls):
-        if not issubclass(element_cls, BaseEntity):
-            raise AssertionError(
-                f"Element {element_cls.__name__} must be subclass of `BaseEntity`"
-            )
+    def _derive_preference(cls, kwargs: Dict, key: str, default: Any) -> Any:
+        """A common method to pop an element's preference from multiple sources
 
-        if element_cls.meta_.abstract is True:
-            raise NotSupportedError(
-                f"{element_cls.__name__} class has been marked abstract"
-                f" and cannot be instantiated"
-            )
+        Args:
+            kwargs (Dict): Explicit options provided for element
+            element_cls (Any): The Domain Element to which options may be attached
+            key (str): The attribute to derive
+            default (Any): The default if no options are set
 
-        return True
+        Returns:
+            Any: The attribute value
+        """
+        return (
+            kwargs.pop(key, None)
+            or (hasattr(cls.meta_, key) and getattr(cls.meta_, key))
+            or default
+        )
+
+
+def entity_factory(element_cls, **kwargs):
+    element_cls = derive_element_class(element_cls, BaseEntity, **kwargs)
+
+    if element_cls.meta_.abstract is True:
+        raise NotSupportedError(
+            f"{element_cls.__name__} class has been marked abstract"
+            f" and cannot be instantiated"
+        )
+
+    if not element_cls.meta_.aggregate_cls:
+        raise IncorrectUsageError(
+            f"Entity `{element_cls.__name__}` needs to be associated with an Aggregate"
+        )
+
+    return element_cls
