@@ -1,6 +1,7 @@
 """ Module defines utilities for importing modules and packages """
 
-# Standard Library Imports
+import importlib.util
+
 from importlib import import_module
 
 
@@ -18,14 +19,22 @@ def perform_import(val):
     return val
 
 
-def import_from_string(val):
+def import_from_string(val, package=None):
     """
     Attempt to import a class from a string representation.
     """
     try:
         module_path, class_name = val.rsplit(".", 1)
-        module = import_module(module_path)
+        module = import_module(module_path, package=package)
         return getattr(module, class_name)
     except (ImportError, AttributeError) as e:
         msg = f"Could not import {val}. {e.__class__.__name__}: {e}"
         raise ImportError(msg)
+
+
+def import_from_full_path(domain, path):
+    spec = importlib.util.spec_from_file_location(domain, path)
+    mod = importlib.util.module_from_spec(spec)
+    spec.loader.exec_module(mod)
+
+    return getattr(mod, domain)
