@@ -1,4 +1,3 @@
-# Protean
 from protean.core.aggregate import BaseAggregate
 from protean.core.field.basic import String
 from protean.utils import fully_qualified_name
@@ -11,7 +10,7 @@ class TestAggregateRegistration:
 
         test_domain.register(User)
 
-        assert fully_qualified_name(User) in test_domain.aggregates
+        assert fully_qualified_name(User) in test_domain.registry.aggregates
 
     def test_settings_in_manual_registration(self, test_domain):
         class User(BaseAggregate):
