@@ -1,10 +1,8 @@
-# Protean
 import pytest
 
 from protean.core.application_service import BaseApplicationService
 from protean.utils import fully_qualified_name
 
-# Local/Relative Imports
 from .elements import DummyApplicationService
 
 
@@ -24,7 +22,7 @@ class TestApplicationServiceRegistration:
 
         assert (
             fully_qualified_name(DummyApplicationService)
-            in test_domain.application_services
+            in test_domain.registry.application_services
         )
 
     def test_that_application_service_can_be_registered_via_annotations(
@@ -37,5 +35,5 @@ class TestApplicationServiceRegistration:
 
         assert (
             fully_qualified_name(AnnotatedApplicationService)
-            in test_domain.application_services
+            in test_domain.registry.application_services
         )
