@@ -1,4 +1,3 @@
-# Protean
 from protean.utils import Database, IdentityStrategy, IdentityType
 
 DEBUG = True
@@ -12,16 +11,16 @@ SECRET_KEY = "j2t#8U!vy877Rn2W6gQQyz%HmXN3@egV"
 # Database Configuration
 DATABASES = {
     "default": {
-        "PROVIDER": "protean.impl.repository.sqlalchemy_repo.SAProvider",
+        "PROVIDER": "protean.adapters.repository.sqlalchemy.SAProvider",
         "DATABASE": Database.SQLITE.value,
         "DATABASE_URI": "sqlite:///test.db",
     },
 }
 
-IDENTITY_STRATEGY = IdentityStrategy.UUID
-IDENTITY_TYPE = IdentityType.INTEGER
+IDENTITY_STRATEGY = IdentityStrategy.UUID.value
+IDENTITY_TYPE = IdentityType.INTEGER.value
 
 # Messaging Mediums
 BROKERS = {
-    "default": {"PROVIDER": "protean.impl.broker.memory_broker.MemoryBroker"},
+    "default": {"PROVIDER": "protean.adapters.InlineBroker"},
 }
