@@ -1,6 +1,5 @@
 # cSpell: disable
 
-# Protean
 from protean.utils import Database, IdentityStrategy, IdentityType
 
 DEBUG = True
@@ -14,16 +13,16 @@ SECRET_KEY = "BuyDV45%6R%hdNqDvex@6nB7@yscjQta"
 # Database Configuration
 DATABASES = {
     "default": {
-        "PROVIDER": "protean.impl.repository.sqlalchemy_repo.SAProvider",
+        "PROVIDER": "protean.adapters.repository.sqlalchemy.SAProvider",
         "DATABASE": Database.SQLITE.value,
         "DATABASE_URI": "sqlite:///test.db",
     },
 }
 
-IDENTITY_STRATEGY = IdentityStrategy.UUID
-IDENTITY_TYPE = IdentityType.STRING
+IDENTITY_STRATEGY = IdentityStrategy.UUID.value
+IDENTITY_TYPE = IdentityType.STRING.value
 
 # Messaging Mediums
 BROKERS = {
-    "default": {"PROVIDER": "protean.impl.broker.memory_broker.MemoryBroker"},
+    "default": {"PROVIDER": "protean.adapters.InlineBroker"},
 }
