@@ -1,14 +1,12 @@
-# Standard Library Imports
 import re
 
 from collections import defaultdict
 from typing import List
 
-# Protean
 from protean.core.aggregate import BaseAggregate
 from protean.core.field.basic import Integer, String
-from protean.core.field.embedded import ValueObjectField
-from protean.core.repository.base import BaseRepository
+from protean.core.field.embedded import ValueObject
+from protean.core.repository import BaseRepository
 from protean.core.value_object import BaseValueObject
 from protean.globals import current_domain
 
@@ -44,5 +42,5 @@ class Email(BaseValueObject):
 
 
 class User(BaseAggregate):
-    email = ValueObjectField(Email, required=True)
+    email = ValueObject(Email, required=True)
     password = String(required=True, max_length=255)
