@@ -1,12 +1,10 @@
-# Standard Library Imports
 from datetime import datetime
 
-# Protean
 from protean.core.aggregate import BaseAggregate
 from protean.core.entity import BaseEntity
 from protean.core.field.association import HasMany, HasOne, Reference
 from protean.core.field.basic import DateTime, Integer, String, Text
-from protean.core.repository.base import BaseRepository
+from protean.core.repository import BaseRepository
 
 
 class Post(BaseAggregate):
