@@ -1,7 +1,6 @@
-# Protean
 from protean.core.aggregate import BaseAggregate
 from protean.core.field.basic import Integer, String
-from protean.core.repository.base import BaseRepository
+from protean.core.repository import BaseRepository
 
 
 class Person(BaseAggregate):
