@@ -1,8 +1,7 @@
-# Protean
 import pytest
 
-from protean.core.exceptions import InvalidOperationError
 from protean.core.unit_of_work import UnitOfWork
+from protean.exceptions import InvalidOperationError
 
 
 class TestUnitOfWorkInitialization:
